==> spip_4.2.9+dfsg.orig.tar.xz: ecrire/lang/public_pl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=pl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Strona główna', # MODIF
	'article' => 'Artykuł',
	'articles' => 'Artykuły',
	'articles_auteur' => 'Artykuły napisane przez tego autora',
	'articles_populaires' => 'Najbardziej popularne artykuły',
	'articles_rubrique' => 'Artykuły w tym dziale',
	'aucun_article' => 'Nie ma żadnego artykułu pod tym adresem',
	'aucun_auteur' => 'Nie ma żadnego autora pod tym adresem',
	'aucun_site' => 'Nie ma żadnej strony pod tym adresem',
	'aucune_breve' => 'Nie ma żadnego newsa pod tym adresem ',
	'aucune_rubrique' => 'Nie ma żadnego działu pod tym adresem',
	'auteur' => 'Autor',
	'autres' => 'Inne',
	'autres_breves' => 'Reszta aktualności',
	'autres_groupes_mots_clefs' => 'Inne grupy słów kluczowych',
	'autres_sites' => 'Inne strony',

	// B
	'bonjour' => 'Dzień dobry',

	// C
	'commenter_site' => 'Dodaj komentarz na temat strony',
	'contact' => 'Kontakt',
	'copie_document_impossible' => 'Kopiowanie tego dokumentu jest uniemożliwione',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Dodane ostatnio',
	'dernieres_breves' => 'Najnowsze aktualności',
	'derniers_articles' => 'Najnowsze artykuły',
	'derniers_commentaires' => 'Ostatnie komentarze',
	'derniers_messages_forum' => 'Ostatnie wiadomości opublikowane w forum',

	// E
	'edition_mode_texte' => 'Edycja w trybie tekstowym',
	'en_reponse' => 'W odpowiedzi na :',
	'en_resume' => 'W skrócie',
	'envoyer_message' => 'Wyślij wiadomość',
	'espace_prive' => 'Strefa prywatna',

	// F
	'formats_acceptes' => 'Ważne formaty: @formats@.',

	// H
	'hierarchie_site' => 'Mapa strony',

	// J
	'jours' => 'dni',

	// L
	'lien_connecter' => 'Zaloguj się',

	// M
	'meme_auteur' => 'Ten sam autor',
	'meme_rubrique' => 'W tym samym dziale',
	'memes_auteurs' => 'Tych samych autorów',
	'message' => 'Wiadomość',
	'messages_forum' => 'Wiadomości na forum', # MODIF
	'messages_recents' => 'Najnowsze wiadomości na forum',
	'mots_clef' => 'Słowo kluczowe',
	'mots_clefs' => 'Słowa kluczowe',
	'mots_clefs_meme_groupe' => 'Słowa kluczowe z tej samej grupy',

	// N
	'navigation' => 'Nawigacja',
	'nom' => 'Nazwisko',
	'nouveautes' => 'Nowości',
	'nouveautes_web' => 'Nowości w Internecie',
	'nouveaux_articles' => 'NOwe artykuły',
	'nouvelles_breves' => 'Najnowsze aktualności',

	// P
	'page_precedente' => 'poprzednia strona',
	'page_suivante' => 'następna strona',
	'par_auteur' => 'przez',
	'participer_site' => 'Możesz wziąć udział w tworzeniu tego serwisu i proponować własne artykuły. Aby mieć taką możliwość, musisz się zapisać poniżej. Na podany adres e-mail otrzymasz hasło dostępu do strefy prywatnej serwisu.',
	'plan_site' => 'Mapa strony',
	'popularite' => 'Popularność',
	'poster_message' => 'Napisz wiadomość',
	'proposer_site' => 'Możes zaproponować stronę do dodania w tym katalogu:',

	// R
	'repondre_article' => 'Skomentuj ten artykuł',
	'repondre_breve' => 'Skomentuj ten news',
	'resultats_recherche' => 'Wynik wyszukiwania',
	'retour_debut_forums' => 'Powrót do strony głównej forum',
	'rubrique' => 'Dział',
	'rubriques' => 'Działy',

	// S
	'signatures_petition' => 'Podpisy',
	'site_realise_avec_spip' => 'Strona zrealizowana przy pomocy SPIP',
	'sites_web' => 'Strony internetowe',
	'sous_rubriques' => 'Pod-działy',
	'spam' => 'Spam',
	'suite' => 'więcej',
	'sur_web' => 'W internecie',
	'syndiquer_rubrique' => 'Ten dział',
	'syndiquer_site' => 'Całą stronę',

	// T
	'texte_lettre_information' => 'Poniżej lista subskrypcyjna serwisu',
	'texte_lettre_information_2' => 'Na tej liście znajdziesz archiwum artykułów i aktualności opublikowanych od', # MODIF

	// V
	'ver_imprimer' => 'Wersja do druku',
	'voir_en_ligne' => 'Zobacz on-line',
	'voir_squelette' => 'zobacz szkielet/template strony'
);

==> spip_4.4.7+dfsg.orig.tar.xz: ecrire/lang/public_pl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=pl
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Strona główna', # MODIF
	'article' => 'Artykuł',
	'articles' => 'Artykuły',
	'articles_auteur' => 'Artykuły napisane przez tego autora',
	'articles_populaires' => 'Najbardziej popularne artykuły',
	'articles_rubrique' => 'Artykuły w tym dziale',
	'aucun_article' => 'Nie ma żadnego artykułu pod tym adresem',
	'aucun_auteur' => 'Nie ma żadnego autora pod tym adresem',
	'aucun_site' => 'Nie ma żadnej strony pod tym adresem',
	'aucune_breve' => 'Nie ma żadnego newsa pod tym adresem ',
	'aucune_rubrique' => 'Nie ma żadnego działu pod tym adresem',
	'auteur' => 'Autor',
	'autres' => 'Inne',
	'autres_breves' => 'Reszta aktualności',
	'autres_groupes_mots_clefs' => 'Inne grupy słów kluczowych',
	'autres_sites' => 'Inne strony',

	// B
	'bonjour' => 'Dzień dobry',

	// C
	'commenter_site' => 'Dodaj komentarz na temat strony',
	'contact' => 'Kontakt',
	'copie_document_impossible' => 'Kopiowanie tego dokumentu jest uniemożliwione',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Dodane ostatnio',
	'dernieres_breves' => 'Najnowsze aktualności',
	'derniers_articles' => 'Najnowsze artykuły',
	'derniers_commentaires' => 'Ostatnie komentarze',
	'derniers_messages_forum' => 'Ostatnie wiadomości opublikowane w forum',

	// E
	'edition_mode_texte' => 'Edycja w trybie tekstowym',
	'en_reponse' => 'W odpowiedzi na :',
	'en_resume' => 'W skrócie',
	'envoyer_message' => 'Wyślij wiadomość',
	'espace_prive' => 'Strefa prywatna',

	// F
	'formats_acceptes' => 'Ważne formaty: @formats@.',

	// H
	'hierarchie_site' => 'Mapa strony',

	// J
	'jours' => 'dni',

	// L
	'lien_connecter' => 'Zaloguj się',

	// M
	'meme_auteur' => 'Ten sam autor',
	'meme_rubrique' => 'W tym samym dziale',
	'memes_auteurs' => 'Tych samych autorów',
	'message' => 'Wiadomość',
	'messages_forum' => 'Wiadomości na forum', # MODIF
	'messages_recents' => 'Najnowsze wiadomości na forum',
	'mots_clef' => 'Słowo kluczowe',
	'mots_clefs' => 'Słowa kluczowe',
	'mots_clefs_meme_groupe' => 'Słowa kluczowe z tej samej grupy',

	// N
	'navigation' => 'Nawigacja',
	'nom' => 'Nazwisko',
	'nouveautes' => 'Nowości',
	'nouveautes_web' => 'Nowości w Internecie',
	'nouveaux_articles' => 'NOwe artykuły',
	'nouvelles_breves' => 'Najnowsze aktualności',

	// P
	'page_precedente' => 'poprzednia strona',
	'page_suivante' => 'następna strona',
	'par_auteur' => 'przez',
	'participer_site' => 'Możesz wziąć udział w tworzeniu tego serwisu i proponować własne artykuły. Aby mieć taką możliwość, musisz się zapisać poniżej. Na podany adres e-mail otrzymasz hasło dostępu do strefy prywatnej serwisu.',
	'plan_site' => 'Mapa strony',
	'popularite' => 'Popularność',
	'poster_message' => 'Napisz wiadomość',
	'proposer_site' => 'Możes zaproponować stronę do dodania w tym katalogu:',

	// R
	'repondre_article' => 'Skomentuj ten artykuł',
	'repondre_breve' => 'Skomentuj ten news',
	'resultats_recherche' => 'Wynik wyszukiwania',
	'retour_debut_forums' => 'Powrót do strony głównej forum',
	'rubrique' => 'Dział',
	'rubriques' => 'Działy',

	// S
	'signatures_petition' => 'Podpisy',
	'site_realise_avec_spip' => 'Strona zrealizowana przy pomocy SPIP',
	'sites_web' => 'Strony internetowe',
	'sous_rubriques' => 'Pod-działy',
	'spam' => 'Spam',
	'suite' => 'więcej',
	'sur_web' => 'W internecie',
	'syndiquer_rubrique' => 'Ten dział',
	'syndiquer_site' => 'Całą stronę',

	// T
	'texte_lettre_information' => 'Poniżej lista subskrypcyjna serwisu',
	'texte_lettre_information_2' => 'Na tej liście znajdziesz archiwum artykułów i aktualności opublikowanych od', # MODIF

	// V
	'ver_imprimer' => 'Wersja do druku',
	'voir_en_ligne' => 'Zobacz on-line',
	'voir_squelette' => 'zobacz szkielet/template strony',
];
